Accessor<Source, Focus> typedef

Accessor<Source, Focus> = Focus Function(Source source)

A function that retrieves a Focus value from a Source value.

This is the "getter" half of an optic, allowing you to view into a data structure.

Implementation

typedef Accessor<Source, Focus> = Focus Function(Source source);